==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractNegExpr.h <==
// public abstract class soot.jimple.internal.AbstractNegExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractUnopExpr

#include "soot/jimple/internal/AbstractUnopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractNegExpr_H_
#define _JC_soot_jimple_internal_AbstractNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	_jc_soot_jimple_internal_AbstractNegExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$refs	_jc_soot_jimple_internal_AbstractNegExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$nonrefs	_jc_soot_jimple_internal_AbstractNegExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$object	_jc_soot_jimple_internal_AbstractNegExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractNegExpr$vmethods	_jc_soot_jimple_internal_AbstractNegExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractNegExpr$vtable	_jc_soot_jimple_internal_AbstractNegExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractNegExpr$vtype	_jc_soot_jimple_internal_AbstractNegExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractNegExpr$method$_init$42e949dc1de144e1(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractNegExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
extern jint _jc_soot_jimple_internal_AbstractNegExpr$method$equivHashCode$a61e38ee84d179c1(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
extern jboolean _jc_soot_jimple_internal_AbstractNegExpr$method$equivTo$4576338963d2dec1(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_soot_Type$object *_jc_soot_jimple_internal_AbstractNegExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_AbstractNegExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
extern void _jc_soot_jimple_internal_AbstractNegExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$equivHashCode$a61e38ee84d179c1;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$equivTo$4576338963d2dec1;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractNegExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
	jint	(*equivHashCode$a61e38ee84d179c1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
	jboolean	(*equivTo$4576338963d2dec1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_java_lang_Object$object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractNegExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractNegExpr$refs {
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractNegExpr$object {
	_jc_soot_jimple_internal_AbstractNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractNegExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractNegExpr$vtype _jc_soot_jimple_internal_AbstractNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractNegExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractNegExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractNegExpr.h <==
// public abstract class soot.jimple.internal.AbstractNegExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractUnopExpr

#include "soot/jimple/internal/AbstractUnopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractNegExpr_H_
#define _JC_soot_jimple_internal_AbstractNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	_jc_soot_jimple_internal_AbstractNegExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$refs	_jc_soot_jimple_internal_AbstractNegExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$nonrefs	_jc_soot_jimple_internal_AbstractNegExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractNegExpr$object	_jc_soot_jimple_internal_AbstractNegExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractNegExpr$vmethods	_jc_soot_jimple_internal_AbstractNegExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractNegExpr$vtable	_jc_soot_jimple_internal_AbstractNegExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractNegExpr$vtype	_jc_soot_jimple_internal_AbstractNegExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractNegExpr$method$_init$42e949dc1de144e1(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_AbstractNegExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_AbstractNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_internal_AbstractNegExpr$method$equivHashCode$a61e38ee84d179c1(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_internal_AbstractNegExpr$method$equivTo$4576338963d2dec1(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_jimple_internal_AbstractNegExpr$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_AbstractNegExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_AbstractNegExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$equivHashCode$a61e38ee84d179c1;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$equivTo$4576338963d2dec1;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$getType$847707b1f3b96fef;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_jimple_internal_AbstractNegExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractNegExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
	jint	(*equivHashCode$a61e38ee84d179c1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
	jboolean	(*equivTo$4576338963d2dec1)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_jimple_internal_AbstractNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractNegExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractNegExpr$refs {
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractNegExpr$object {
	_jc_soot_jimple_internal_AbstractNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractNegExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractNegExpr$vtype _jc_soot_jimple_internal_AbstractNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractNegExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractNegExpr_H_ */
